<nav class="navbar navbar-inverse navbar-static-top" role="navigation">
	<div class="container">
		<a class="navbar-brand" href="{% url 'store:movie_list' %}">Boilerplate Demo</a>
		<ul class="nav navbar-nav">
			<li>
				<a href="{% url 'store:movie_list' %}">Movies</a>
			</li>
			<li>
				<a href="{% url 'store:actor_list' %}">Actors</a>
			</li>
			<li>
				<a href="http://django-boilerplate-docs.readthedocs.io" target="_blank">Documentation</a>
			</li>
		</ul>

		<ul class="nav navbar-nav navbar-right">
			{% if request.user.is_authenticated %}
			<li>
				<a href="{% url 'account:password' %}">Change Password</a>
			</li>
			<li>
				<a href="{% url 'account:logout' %}">Logout</a>
			</li>
			{% else %}
			<li>
				<a href="{% url 'account:login' %}">Login</a>
			</li>
			<li>
				<a href="{% url 'account:registration' %}">Register</a>
			</li>
			{% endif %}
		</ul>
	</div>
</nav>